@@ -1,11 +1,11 @@
 """This module provides ``kedro.abstract_config`` with the baseline
 class model for a `ConfigLoader` implementation.
 """
-from abc import ABC, abstractmethod
+from collections import UserDict
 from typing import Any, Dict
 
 
-class AbstractConfigLoader(ABC):
+class AbstractConfigLoader(UserDict):
     """``AbstractConfigLoader`` is the abstract base class
         for all `ConfigLoader` implementations.
     All user-defined `ConfigLoader` implementations should inherit
@@ -17,17 +17,13 @@ class AbstractConfigLoader(ABC):
         conf_source: str,
         env: str = None,
         runtime_params: Dict[str, Any] = None,
-        **kwargs  # pylint: disable=unused-argument
+        **kwargs
     ):
+        super().__init__()
         self.conf_source = conf_source
         self.env = env
         self.runtime_params = runtime_params
 
-    @abstractmethod  # pragma: no cover
-    def get(self) -> Dict[str, Any]:
-        """Required method to get all configurations."""
-        pass
-
 
 class BadConfigException(Exception):
     """Raised when a configuration file cannot be loaded, for instance
