@@ -17,27 +17,26 @@ class APIDataSet(AbstractDataSet[None, requests.Response]):
     """``APIDataSet`` loads the data from HTTP(S) APIs.
     It uses the python requests library: https://requests.readthedocs.io/en/latest/
 
-    Example adding a catalog entry with
-    `YAML API
-    <https://kedro.readthedocs.io/en/stable/data/\
-        data_catalog.html#use-the-data-catalog-with-the-yaml-api>`_:
+    Example usage for the
+    `YAML API <https://kedro.readthedocs.io/en/stable/data/\
+    data_catalog.html#use-the-data-catalog-with-the-yaml-api>`_:
 
     .. code-block:: yaml
 
-        >>> usda:
-        >>>   type: api.APIDataSet
-        >>>   url: https://quickstats.nass.usda.gov
-        >>>   params:
-        >>>     key: SOME_TOKEN,
-        >>>     format: JSON,
-        >>>     commodity_desc: CORN,
-        >>>     statisticcat_des: YIELD,
-        >>>     agg_level_desc: STATE,
-        >>>     year: 2000
-        >>>
+        usda:
+          type: api.APIDataSet
+          url: https://quickstats.nass.usda.gov
+          params:
+            key: SOME_TOKEN,
+            format: JSON,
+            commodity_desc: CORN,
+            statisticcat_des: YIELD,
+            agg_level_desc: STATE,
+            year: 2000
 
-
-    Example using Python API:
+    Example usage for the
+    `Python API <https://kedro.readthedocs.io/en/stable/data/\
+    data_catalog.html#use-the-data-catalog-with-the-code-api>`_:
     ::
 
         >>> from kedro.extras.datasets.api import APIDataSet
@@ -117,7 +116,7 @@ class APIDataSet(AbstractDataSet[None, requests.Response]):
         }
 
     def _describe(self) -> Dict[str, Any]:
-        return dict(**self._request_args)
+        return {**self._request_args}
 
     def _execute_request(self) -> requests.Response:
         try:
