@@ -146,15 +146,15 @@ class EmailMessageDataSet(
         self._fs_open_args_save = _fs_open_args_save
 
     def _describe(self) -> Dict[str, Any]:
-        return dict(
-            filepath=self._filepath,
-            protocol=self._protocol,
-            load_args=self._load_args,
-            parser_args=self._parser_args,
-            save_args=self._save_args,
-            generator_args=self._generator_args,
-            version=self._version,
-        )
+        return {
+            "filepath": self._filepath,
+            "protocol": self._protocol,
+            "load_args": self._load_args,
+            "parser_args": self._parser_args,
+            "save_args": self._save_args,
+            "generator_args": self._generator_args,
+            "version": self._version,
+        }
 
     def _load(self) -> Message:
         load_path = get_filepath_str(self._get_load_path(), self._protocol)
