@@ -469,7 +469,7 @@ def _split_params(ctx, param, value):
             )
         dot_list.append(item)
     conf = OmegaConf.from_dotlist(dot_list)
-    return conf
+    return OmegaConf.to_container(conf)
 
 
 def _split_load_versions(ctx, param, value):
