@@ -3,8 +3,8 @@ This is a boilerplate pipeline '{{ cookiecutter.pipeline_name }}'
 generated using Kedro {{ cookiecutter.kedro_version }}
 """
 
-from kedro.pipeline import Pipeline, node
+from kedro.pipeline import Pipeline, node, pipeline
 
 
-def create_pipeline(**kwargs):
-    return Pipeline([])
+def create_pipeline(**kwargs) -> Pipeline:
+    return pipeline([])
